## *Function* `validate(self) -> bool`


Return True if valid.

Raises NeuronConnectomeValidatorError if invalid.


## *Function* `validate(self, g: nx.Graph, u, v, type=None, exists: bool = True) -> bool`


Return True if valid.

Raises DisagreeingEdgesValidatorError if invalid.
